@@ -20,7 +20,7 @@
 import sys, os, platform
 from PyQt4 import QtCore
 # specifically import from PyQt4.QtGui for startup time improvement :
-from PyQt4.QtGui import QMainWindow, QVBoxLayout, QErrorMessage, QApplication, QPixmap, QSplashScreen
+from PyQt4.QtGui import QMainWindow, QVBoxLayout, QErrorMessage, QApplication, QPixmap, QSplashScreen, QMessageBox
 from friture.ui_friture import Ui_MainWindow
 from friture.dock import Dock
 from friture.about import About_Dialog # About dialog
@@ -62,6 +62,15 @@ STYLESHEET = """
 #}
 #"""
 
+no_input_device_title = "No audio input device found"
+
+no_input_device_message = """No audio input device has been found.
+
+Please check your audio configuration.
+
+Friture will now exit.
+"""
+
 class Friture(QMainWindow, ):
 	def __init__(self, logger):
 		QMainWindow.__init__(self)
@@ -83,12 +92,19 @@ class Friture(QMainWindow, ):
 		self.cpu_percent = 0.
 
 		# Initialize the audio data ring buffer
-		self.audiobuffer = AudioBuffer()
+		self.audiobuffer = AudioBuffer(self.logger)
 
 		# Initialize the audio backend
 		self.audiobackend = AudioBackend(self.logger)
-   
+
 		devices = self.audiobackend.get_readable_devices_list()
+
+		if devices == []:
+			# no audio input device: display a message and exit
+			QMessageBox.critical(self, no_input_device_title, no_input_device_message)
+			QtCore.QTimer.singleShot(0, self.exitOnInit)
+			return
+
 		for device in devices:
 			self.settings_dialog.comboBox_inputDevice.addItem(device)
 
@@ -137,7 +153,6 @@ class Friture(QMainWindow, ):
 		self.connect(self.settings_dialog.comboBox_secondChannel, QtCore.SIGNAL('currentIndexChanged(int)'), self.second_channel_changed)
 		self.connect(self.settings_dialog.radioButton_single, QtCore.SIGNAL('toggled(bool)'), self.single_input_type_selected)
 		self.connect(self.settings_dialog.radioButton_duo, QtCore.SIGNAL('toggled(bool)'), self.duo_input_type_selected)
-		self.connect(self.settings_dialog.doubleSpinBox_delay, QtCore.SIGNAL('valueChanged(double)'), self.delay_changed)
 
 		# log change
 		self.connect(self.logger, QtCore.SIGNAL('logChanged'), self.log_changed)
@@ -152,6 +167,11 @@ class Friture(QMainWindow, ):
 		
 		self.logger.push("Init finished, entering the main loop")
 	
+	# slot
+	# used when no audio input device has been found, to exit immediately
+	def exitOnInit(self):
+		QApplication.instance().quit()
+
 	# slot
 	# update the log widget with the new log content
 	def log_changed(self):
@@ -364,8 +384,6 @@ class Friture(QMainWindow, ):
 	def single_input_type_selected(self, checked):
                 if checked:
                     self.settings_dialog.groupBox_second.setEnabled(False)
-                    self.settings_dialog.label_delay.setEnabled(False)
-                    self.settings_dialog.doubleSpinBox_delay.setEnabled(False)
                     self.audiobackend.set_single_input()
                     self.logger.push("Switching to single input")
 
@@ -373,17 +391,9 @@ class Friture(QMainWindow, ):
 	def duo_input_type_selected(self, checked):
                 if checked:
                     self.settings_dialog.groupBox_second.setEnabled(True)
-                    self.settings_dialog.label_delay.setEnabled(True)
-                    self.settings_dialog.doubleSpinBox_delay.setEnabled(True)
                     self.audiobackend.set_duo_input()
                     self.logger.push("Switching to difference between two inputs")
 
-	# slot
-	def delay_changed(self, delay_ms):
-                    self.delay_ms = delay_ms
-                    self.logger.push("Delay changed to %f" %delay_ms)
-                    self.audiobuffer.set_delay_ms(delay_ms)
-
 def main():
 	if platform.system() == "Windows":
 		print "Running on Windows"
